@@ -150,9 +150,9 @@ class AsrClient(AbstractClient):
 
     def CreateRecTask(self, request):
         """本接口服务对时长5小时以内的录音文件进行识别，异步返回识别全部结果。
-        <br>• 支持中文普通话、英语、粤语、日语和上海话方言
+        <br>• 支持中文普通话、英语、粤语、日语
         <br>• 支持通用、音视频领域
-        <br>• 支持wav、mp3、m4a、flv、mp4格式
+        <br>• 支持wav、mp3、m4a、flv、mp4、wma、3gp、amr、aac、ogg-opus、flac格式
         <br>• 支持语音 URL 和本地语音文件两种请求方式
         <br>• 语音 URL 的音频时长不能长于5小时，文件大小不超过512MB
         <br>• 本地语音文件不能大于5MB
@@ -274,10 +274,11 @@ class AsrClient(AbstractClient):
 
     def DescribeTaskStatus(self, request):
         """在调用录音文件识别请求接口后，有回调和轮询两种方式获取识别结果。
-        <br>• 当采用回调方式时，识别完成后会将结果通过 POST 请求的形式通知到用户在请求时填写的回调 URL，具体请参见[ 录音识别结果回调 ](https://cloud.tencent.com/document/product/1093/37139#callback)。
+        <br>• 当采用回调方式时，识别完成后会将结果通过 POST 请求的形式通知到用户在请求时填写的回调 URL，具体请参见[ 录音识别结果回调 ](https://cloud.tencent.com/document/product/1093/52632)。
         <br>• 当采用轮询方式时，需要主动提交任务ID来轮询识别结果，共有任务成功、等待、执行中和失败四种结果，具体信息请参见下文说明。
         <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
         <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        <br>•   默认接口请求频率限制：50次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for DescribeTaskStatus.
         :type request: :class:`tencentcloud.asr.v20190614.models.DescribeTaskStatusRequest`
@@ -508,6 +509,7 @@ class AsrClient(AbstractClient):
         <br>•   当音频文件通过请求中body内容上传时，请求大小不能超过3MB。
         <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
         <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        <br>•   默认接口请求频率限制：25次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for SentenceRecognition.
         :type request: :class:`tencentcloud.asr.v20190614.models.SentenceRecognitionRequest`
